California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| CAMPAIGN FINANCE: Candidates & Elected Officials
Choose a Listing: Certified Election Candidates Incumbent Elected State Officials Candidates and Elected Officials By Name Who filed a Statement of Intention to run for What State Office? (Filers may not have qualified for the ballot) CalPERS and CalSTRS Candidate Filings, Scanned Images |
Go to Section:
| Statewide Candidates
| State Senate Candidates
| State Assembly Candidates
Choose an Election: 2022 PRIMARY 2021 SPECIAL ELECTION (ASSEMBLY 54) Prior Elections 2021 SPECIAL ELECTION (ASSEMBLY 79) 2021 SPECIAL ELECTION (STATE SENATE 30) 2020 GENERAL 2020 SPECIAL RUNOFF (STATE SENATE 28) 2020 PRIMARY 2020 SPECIAL ELECTION (STATE SENATE 28) 2019 SPECIAL RUNOFF (ASSEMBLY 01) 2019 SPECIAL ELECTION (ASSEMBLY 01) 2019 SPECIAL RUNOFF (STATE SENATE 01) 2019 SPECIAL RUNOFF (STATE SENATE 33) 2019 SPECIAL ELECTION (STATE SENATE 01) 2019 SPECIAL ELECTION (STATE SENATE 33) 2018 GENERAL 2018 SPECIAL RUNOFF (STATE SENATE 32) 2018 PRIMARY 2018 SPECIAL ELECTION (STATE SENATE 32) 2018 SPECIAL ELECTION (STATE SENATE 29) 2018 SPECIAL RUNOFF (ASSEMBLY 45) 2018 SPECIAL RUNOFF (ASSEMBLY 39) 2018 SPECIAL ELECTION (ASSEMBLY 45) 2018 SPECIAL ELECTION (ASSEMBLY 54) 2018 SPECIAL ELECTION (ASSEMBLY 39) 2017 SPECIAL RUNOFF (ASSEMBLY 51) 2017 SPECIAL ELECTION (ASSEMBLY 51) 2016 GENERAL 2016 PRIMARY 2016 SPECIAL ELECTION (ASSEMBLY 31) 2015 SPECIAL RUNOFF (STATE SENATE 07) 2015 SPECIAL ELECTION (STATE SENATE 37) 2015 SPECIAL ELECTION (STATE SENATE 21) 2015 SPECIAL ELECTION (STATE SENATE 07) 2014 SPECIAL ELECTION (STATE SENATE 35) 2014 GENERAL 2014 PRIMARY 2014 SPECIAL ELECTION (STATE SENATE 23) 2013 SPECIAL ELECTION (ASSEMBLY 54) 2013 SPECIAL RUNOFF (ASSEMBLY 45) 2013 SPECIAL RUNOFF (ASSEMBLY 52) 2013 SPECIAL ELECTION (STATE SENATE 26) 2013 SPECIAL ELECTION (ASSEMBLY 45) 2013 SPECIAL ELECTION (ASSEMBLY 52) 2013 SPECIAL RUNOFF (STATE SENATE 16) 2013 SPECIAL ELECTION (ASSEMBLY 80) 2013 SPECIAL ELECTION (STATE SENATE 16) 2013 SPECIAL RUNOFF (STATE SENATE 32) 2013 SPECIAL ELECTION (STATE SENATE 40) 2013 SPECIAL ELECTION (STATE SENATE 32) 2013 SPECIAL ELECTION (STATE SENATE 04) 2012 GENERAL 2012 SPECIAL ELECTION (STATE SENATE 04) 2012 PRIMARY 2011 SPECIAL RUNOFF (ASSEMBLY 04) 2011 SPECIAL ELECTION (ASSEMBLY 04) 2011 SPECIAL ELECTION (STATE SENATE 17) 2011 SPECIAL ELECTION (STATE SENATE 28) 2011 SPECIAL RUNOFF (STATE SENATE 01) 2010 GENERAL 2010 SPECIAL ELECTION (STATE SENATE 01) 2010 SPECIAL RUNOFF (STATE SENATE 15) 2010 SPECIAL ELECTION (STATE SENATE 15) 2010 PRIMARY 2010 SPECIAL RUNOFF (STATE SENATE 37) 2010 SPECIAL RUNOFF (ASSEMBLY 43) 2010 SPECIAL ELECTION (STATE SENATE 37) 2010 SPECIAL ELECTION (ASSEMBLY 43) 2010 SPECIAL RUNOFF (ASSEMBLY 72) 2009 SPECIAL ELECTION (ASSEMBLY 72) 2009 SPECIAL ELECTION (ASSEMBLY 51) 2009 SPECIAL RUNOFF (STATE SENATE 26) 2009 SPECIAL ELECTION (STATE SENATE 26) 2008 GENERAL 2008 PRIMARY 2008 RECALL (STATE SENATE 12) 2008 SPECIAL RUNOFF (ASSEMBLY 55) 2007 SPECIAL ELECTION (ASSEMBLY 55) 2007 SPECIAL ELECTION (ASSEMBLY 39) 2006 GENERAL 2006 PRIMARY 2006 SPECIAL RUNOFF (STATE SENATE 35) 2006 SPECIAL ELECTION (STATE SENATE 35) 2005 SPECIAL ELECTION (ASSEMBLY 53) 2004 GENERAL 2004 PRIMARY 2003 SPECIAL ELECTION (GOVERNOR) 2002 GENERAL 2002 PRIMARY 2001 SPECIAL ELECTION (ASSEMBLY 49) 2001 SPECIAL RUNOFF (ASSEMBLY 65) 2001 SPECIAL ELECTION (STATE SENATE 24) 2001 SPECIAL ELECTION (ASSEMBLY 65) 2000 GENERAL 2000 PRIMARY
Also check Late Contribution filings. These reports are independent of the comprehensive disclosure reports that are linked here until semi-annual filings are submitted.
STATEWIDE OFFICES
GOVERNOR
ADAM, IRIS CAMEJO, PETER MIGUEL COPELAND, GARY DAVID DAVIS, GRAY GULKE, REINHOLD SIMON JR., WILLIAM E.
| LIEUTENANT GOVERNOR
BUSTAMANTE, CRUZ M. HANNOSH, PAUL J. KING, JIM MC PHERSON, BRUCE PRZYBYLAK, KALEE WARREN, DONNA J. WRIGHT, PAT
SECRETARY OF STATE
ALLISON, LOUISE M. LIGHTFOOT, GAIL K. NOONAN, EDWARD C. OLBERG, KEITH R. SHARPE-GEISLER, VALLI SHELLEY, KEVIN SHOUP, LAURENCE H.
| CONTROLLER
AGUIRRE, CARLOS MC CLINTOCK, THOMAS VANCE, ERNEST F. WELLS, LAURA WESTLY, STEVE
TREASURER
ANGELIDES, PHIL CONLON, GREG JOHNSON, NATHAN E. ROSENMEIER, JEANNE-MARIE SMITHSON, MARIAN V. VALENTINE, SYLVIA ESTHER
| ATTORNEY GENERAL
ACKERMAN, RICHARD KUWATCH, EDWARD J. LOCKYER, BILL MOWRER, GLEN FREEMAN TEMPLIN, DIANE BEALL
SUPERINTENDENT OF PUBLIC INSTRUCTION
O'CONNELL, JACK SMITH, KATHERINE H.
| INSURANCE COMMISSIONER
CALDERON JR., RAUL GARAMENDI, JOHN KLEIN, STEVEN MENDOZA, GARY S. OGDEN, DALE F. SHEIDLOWER, DAVID I.
BOARD OF EQUALIZATION
MEMBER BOARD OF EQUALIZATION 01
BENDICK, MARK S. BRIERLY, ELIZABETH C MIGDEN, CAROLE
| MEMBER BOARD OF EQUALIZATION 02
LEONARD, BILL SANTOS, TOM Y.
MEMBER BOARD OF EQUALIZATION 03
CHRISTIAN-HEISING, MARY GRAHAM, J.R. PARRISH, CLAUDE
| MEMBER BOARD OF EQUALIZATION 04
CHIANG, JOHN FORSCH, GLEN R. WEISSMAN, KENNETH A.
SENATE DISTRICTS
STATE SENATE 02
CHESBRO, WESLEY LIKOVER, LAURA J. REDFEARN, PEGGY
| STATE SENATE 04
AANESTAD, SAMUEL M. SMITH, MARIANNE BOPP UNDERWOOD, ROBERT H.
STATE SENATE 06
ORTIZ, DEBORAH V. SEWELL, JASON A
| STATE SENATE 08
FLIEGLER, ROBERT SPEIER, JACQUELINE ZELL, DENNIS S.
STATE SENATE 10
DARNELL, ERVAN E. FIGUEROA, LIZ GUNTHER, JAMES G
| STATE SENATE 12
AREIAS, RUSTY DENHAM, JEFF EATON, DAVID
STATE SENATE 14
POOCHIGIAN, CHUCK
| STATE SENATE 16
FLOREZ, DEAN KNOX, BLAIR B.
STATE SENATE 18
ASHBURN, ROY
| STATE SENATE 20
ALARCON, RICHARD
STATE SENATE 22
CEDILLO, GILBERT
| STATE SENATE 24
HOUSE, VINCENT F. ROMERO, GLORIA SWINNEY, CARL M. "MARTY"
STATE SENATE 26
MURRAY, KEVIN
| STATE SENATE 28
BOWEN, DEBRA DE BAETS, PETER D. HILL, JO ANN
STATE SENATE 30
ESCUTIA, MARTHA M. ROBERTSON, JOHN O.
| STATE SENATE 32
ROBERTSON, KENNETH E. SOTO, NELL
STATE SENATE 34
DUNN, JOSEPH GONZALEZ, ARACELI
| STATE SENATE 36
HOLLINGSWORTH, DENNIS METTI, MICHAEL S. WESTALL, ADRIENNE DENISE
STATE SENATE 38
GROSSMITH, LARS R. HANNEMAN, PHILIP G. MORROW, BILL
| STATE SENATE 40
DUCHENY, DENISE MORENO GIORGINO, MICHAEL S. MIRANDA, FELIX JEREMIAH
ASSEMBLY DISTRICTS
ASSEMBLY 01
BERG, PATTY BROWN, ROBERT K. "ROB" THRON, DOUG RILEY
| ASSEMBLY 02
BRET, PETE ANTHONY KINYON, DOUGLAS J LA MALFA, DOUG
ASSEMBLY 03
KEENE, RICHARD J. KING, STUART R. PETERSEN, JON
| ASSEMBLY 04
LESLIE, R. TIM WARREN, DUNCAN SCOTT
ASSEMBLY 05
COX, DAVE LEIBMAN, ROBERTO ULIS, ERIC J.
| ASSEMBLY 06
HITT, KENNETH A. NATION, JOE OLMSTEAD, RICHARD
ASSEMBLY 07
KOZLOWSKI, DAVID J. WIGGINS, PATRICIA ANN
| ASSEMBLY 08
MUNN, JOHN R. WOLK, LOIS
ASSEMBLY 09
PEGOS, DAVID A. POSTON, DOUGLAS STEINBERG, DARRELL
| ASSEMBLY 10
MAESTAS, KATHERINE E. NAKANISHI, ALAN S.
ASSEMBLY 11
CANCIAMILLA, JOSEPH DENNY, JAN LESLIE MANSKE, FRANK J.
| ASSEMBLY 12
DENNY, MICHAEL F. EPSTEIN, HOWARD YEE, LELAND Y.
ASSEMBLY 13
LENO, MARK MADEN, CHRISTOPHER R. NEIRA, GAIL E.
| ASSEMBLY 14
HANCOCK, LONI
ASSEMBLY 15
GERBER, DONNA C. HOUSTON, GUY
| ASSEMBLY 16
ARMSTRONG, RICHARD E. CHAN, WILMA NUGENT, GEORGE J.
ASSEMBLY 17
MATTHEWS, BARBARA MC CABE, BRIAN L.
| ASSEMBLY 18
CORBETT, ELLEN HOVINGH, JACK
ASSEMBLY 19
CHAMBERLAIN, JO GIEDT, ROBERT W. KAWAS, DAVID MULLIN, GENE R.
| ASSEMBLY 20
DOW, DANIEL L. DUTRA, JOHN A. LYON, KEITH A.
ASSEMBLY 21
BELL, JR., RAYMOND M. RUSSELL, JAMES A. SIMITIAN, S. JOSEPH
| ASSEMBLY 22
KAWCZYNSKI, STAN LIEBER, SALLY WATSON, KENNITA L.
ASSEMBLY 23
BLOOMBERG III, WARNER S. DIAZ, MANNY
| ASSEMBLY 24
COHN, REBECCA
ASSEMBLY 25
COGDILL, DAVID E. SMITH, E. DENISE
| ASSEMBLY 26
AGHAZARIAN, GREG HALLINAN, TOM
ASSEMBLY 27
CARTER, CHARLES "CHUCK" LAIRD, JOHN S. SACHTJEN, GORDON D.
| ASSEMBLY 28
HOWARD, JANE SALINAS, SIMON
ASSEMBLY 29
MARTINEZ JR., RICHARD SAMUELIAN, STEVEN N. ZWICKEL, JONATHAN IRA
| ASSEMBLY 30
GARDNER, M. DEAN PARRA, NICOLE
ASSEMBLY 31
REYES, SARAH
| ASSEMBLY 32
MC CARTHY, KEVIN SHEA III, MICHAEL A.
ASSEMBLY 33
HOULGATE, LAURENCE MALDONADO, ABEL
| ASSEMBLY 34
GURROLA, VIRGINIA MAZE, BILL
ASSEMBLY 35
JACKSON, HANNAH-BETH POHL, BOB SAVITCH, CARY BRUCE THOMAS, CRAIG WARREN
| ASSEMBLY 36
DAVENPORT II, ROBERT RUNNER, SHARON
ASSEMBLY 37
STRICKLAND, TONY THOMAS, BRUCE J.
| ASSEMBLY 38
CALDERON, PAULA L. LEMBKE, KARL RICHMAN, KEITH STUART
ASSEMBLY 39
AYAO, ELY DE LA CRUZ MONTANEZ, CINDY
| ASSEMBLY 40
FRIEDMAN, CONSTANCE J. LEVINE, LLOYD
ASSEMBLY 41
KELLY, BRIAN "MAX" CHARLES PAVLEY, FRAN WISSOT, MICHAEL J.
| ASSEMBLY 42
BISSIRI, JEFFREY ALLEN KORETZ, PAUL
ASSEMBLY 43
FROMMER, DARIO GEYER, INGRID MARIE WOREN, SANDOR J.
| ASSEMBLY 44
LIU, CAROL NEW, BOB O'CONNELL, DANIEL B.
ASSEMBLY 45
COOK, JUDY CHAU PHUONG GOLDBERG, JACKIE
| ASSEMBLY 46
ALDANA JR., MANUEL NUNEZ, FABIAN
ASSEMBLY 47
CLEMENS, KEITH LEONARD, JONATHAN WESSON, JR., HERMAN J.
| ASSEMBLY 48
HERDEGEN, NOLAYAN O. RIDLEY-THOMAS, MARK ROBINSON, GERARD T.
ASSEMBLY 49
CHU, JUDY SHEN, GEORGE
| ASSEMBLY 50
FIREBAUGH, MARCO ANTONIO MILLER, GLADYS O.
ASSEMBLY 51
HORTON, JEROME E.
| ASSEMBLY 52
DYMALLY, MERVYN M. ILES, MARK ANTHONY
ASSEMBLY 53
NAKANO, GEORGE WILSON, LINDA
| ASSEMBLY 54
CASTELLANOS, CESAR N. LOWENTHAL, ALAN
ASSEMBLY 55
OROPEZA, JENNY WILSON, GUY
| ASSEMBLY 56
BERMUDEZ, RUDY BRANKTUK SR., JOHN W.
ASSEMBLY 57
CHAVEZ, EDWARD "ED" FAEGRE, LELAND THOMAS MOLL, ANNE M.
| ASSEMBLY 58
BUTLER, DAVID O. CALDERON, RONALD
ASSEMBLY 59
MOUNTJOY, DENNIS SMITH, PATRICK D.
| ASSEMBLY 60
MARTINEZ, ADRIAN LINCOLN PACHECO, ROBERT "BOB"
ASSEMBLY 61
MC LEOD, GLORIA NEGRETE MUNSON, MATTHEW G.
| ASSEMBLY 62
LONGVILLE, JOHN SCOTT, G. EDWARD
ASSEMBLY 63
DUTTON, BOB WALLACE, DORIS LOUISE
| ASSEMBLY 64
BENOIT, JOHN J. MELSH, ROBERT J.
ASSEMBLY 65
BOGH, RUSSELL V. SCHOLES, DARREL R.
| ASSEMBLY 66
BROSTROM, DAVID G. HAYNES, RAYMOND N.
ASSEMBLY 67
ORTON, WILLIAM R. (BILL)
| ASSEMBLY 68
MADDOX, KENNETH SCRIBNER, DOUGLAS JAMES SNOOK, AL
ASSEMBLY 69
CORREA, LOU ROSS, REUBEN A.
| ASSEMBLY 70
CAMPBELL, JOHN B.T. KANE, JOHN P. STUDIER, PAUL L.
ASSEMBLY 71
FOSTER, BEA SPITZER, TODD
| ASSEMBLY 72
CROSS, BRIAN LEE DAUCHER, LYNN NANJUNDAPPA, GANGADHARAPRA
ASSEMBLY 73
BATES, PATRICIA 'PAT' CALZADA, KATHLEEN VONDRUSKA, ROBERT ANTHONY
| ASSEMBLY 74
HERRERA, JOHN STONE, KRISTI WYLAND, MARK B.
ASSEMBLY 75
PLESCIA, GEORGE A. SENECAL, RICHARD J. WITT, CONNIE
| ASSEMBLY 76
BAKER, SARAH DIVINE, BOB KEHOE, CHRISTINE
ASSEMBLY 77
HALL, VIRGIL R. LA SUER, JAY LOWERY, SARAH
| ASSEMBLY 78
HALL, VINCE HENRY HORTON, SHIRLEY MENANNO, MARK
ASSEMBLY 79
CASTRO, JOSHUA FAST, MARK W. VARGAS, JUAN C.
| ASSEMBLY 80
ACUNA JR., JOEY V. GARCIA, BONNIE